/*****************************************************************************/

/*
 *      usbd.h  --  USBD header.
 *
 *      Copyright (C) 1999 Thomas Sailer, sailer@ife.ee.ethz.ch
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Please note that the GPL allows you to use the driver, NOT the radio.
 *  In order to use the radio, you need a license from the communications
 *  authority of your country.
 *
 */

/*****************************************************************************/

#ifndef _USBD_H
#define _USBD_H

/* ---------------------------------------------------------------------- */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "devtree.h"

/* ---------------------------------------------------------------------- */

/* usbd.c */
extern unsigned int verboselevel;
extern unsigned int logging;

extern int lprintf(unsigned int vl, const char *format, ...) __attribute__ ((format (printf, 2, 3)));

/* config.c */

#define DRVTYPE_KMOD    0
#define DRVTYPE_USER    1
#define DRVTYPE_BUILTIN 2

#define DRVFLAG_NEEDED  1
#define DRVFLAG_LOADED  2

struct driver {
	struct list_head list;
	struct list_head matches;

	unsigned int flags;
	unsigned int type;
	const char *name;
};

struct drivermatch {
	struct list_head list;
	int vendorid;
	int productid;
	int class;
	int subclass;
	int protocol;
	unsigned int priority;
};

extern struct list_head driverlist;

extern void parseconfig(void);
extern void dumpconfig(void);

/* loader.c */
extern void initloader(void);
extern int request_module(const char *modulename, int permanent);
extern int remove_module(const char *modulename);
extern void loaddriver(struct driver *drv, struct usbdevnode *dev);
extern void unloaddriver(struct driver *drv, struct usbdevnode *dev);

/* init.c */
extern int usbdinit(int argc, char *argv[]);

/* ---------------------------------------------------------------------- */
#endif /* _USBD_H */
